--
-- MBgearbox
-- 19/07/09
-- MBgearbox for combine
-- guimchevalier from TSF3

MBgearbox = {};

function MBgearbox.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function MBgearbox:load(xmlFile)
	-- gears
    self.numGear = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.gears#count"), 0);
	self.gears = {};
    for i=1, self.numGear do
        local geari = string.format("vehicle.gears.gear%d", i);
        self.gears[i] = getXMLFloat(xmlFile, geari .. "#value");
    end;
	self.miniGear = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.gears#start"), 1);
	self.gearNum = self.miniGear;
	-- hydro
	self.hydro = 0;
	self.oldInput = 1;
	--rpms
	self.rpms = {};
    local rpm1, rpm2, rpm3 = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rpms#motor"));
	self.rpms[1] = {};
    self.rpms[1] = {rpm1, rpm2, rpm3};
    local rpm1, rpm2, rpm3 = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rpms#disp"));
    self.rpms[2] = {};
	self.rpms[2] = {rpm1, rpm2, rpm3};
	self.rpmNum = 1;
	-- real motor sound
	local motorMBSound = getXMLString(xmlFile, "vehicle.motorMBSound#file");
    if motorMBSound ~= nil and motorMBSound ~= "" then
        motorMBSound = Utils.getFilename(motorMBSound, self.baseDirectory);
        self.motorMBSound = createSample("motorMBSound");
        loadSample(self.motorMBSound, motorMBSound, false);
        self.motorMBSoundPitchOffset = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motorMBSound#pitchOffset"), 0);
        self.motorMBSoundVolume = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motorMBSound#volume"), 1.0);
		self.motorMBSoundPitchScale = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motorMBSound#pitchScale"), 0.05);
		self.motorMBSoundPitchMax = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.motorMBSound#pitchMax"), 2.0);
    end;
end;

function MBgearbox:delete()
    if self.motorMBSound ~= nil then
        delete(self.motorMBSound);
    end;
end;

function MBgearbox:mouseEvent(posX, posY, isDown, isUp, button)
end;

function MBgearbox:stopMotor()
    if self.motorMBSound ~= nil then
        stopSample(self.motorMBSound);
    end;
	self.hydro = 0;
end;

function MBgearbox:keyEvent(unicode, sym, modifier, isDown)
    if self:getIsActiveForInput() and self.isEntered then
	    if InputBinding.isPressed(InputBinding.JDTSPEEDUP) and self.gearNum < self.numGear then
			self.gearNum = self.gearNum + 1;
		elseif InputBinding.isPressed(InputBinding.JDTSPEEDDOWN) and self.gearNum > 1 then
			self.gearNum = self.gearNum - 1;
		end;
		
		if InputBinding.isPressed(InputBinding.JDTRPMUP) and self.rpmNum < 3 then
			self.rpmNum = self.rpmNum + 1;
		elseif InputBinding.isPressed(InputBinding.JDTRPMDOWN) and self.rpmNum > 1 then
			self.rpmNum = self.rpmNum - 1;
		end;
	end;
end;

function MBgearbox:startMotor()
	self.playMotorMBSound = true;
	self.oldInput = 1;
end;

function MBgearbox:update(dt)             	
	if self.isEntered and self.isMotorStarted then
		-- hydro
		local input = InputBinding.getAnalogInputAxis(InputBinding.AXIS_FORWARD);
		if InputBinding.isAxisZero(input) then
			input = InputBinding.getDigitalInputAxis(InputBinding.AXIS_FORWARD);
		end;
		if input==0 then
			if InputBinding.isPressed(InputBinding.JDTHYDROUP) then
				input = -1;
			elseif InputBinding.isPressed(InputBinding.JDTHYDRODOWN) then
				input = 1;
			end;
		end;
		if self.hydro == 0 and self.oldInput == 0 and input ~= 0 then
			if input < 0 then
				self.hydro = 5;
			else
				self.hydro = -5;
			end;
		elseif self.hydro ~= 0 then
			if (self.hydro > 0 and input > 0) or (self.hydro < 0 and input < 0) then
				self.hydro = self.hydro - 2*input;
				if self.hydro < 10 and self.hydro > -10 then
					self.hydro = 0;
				end;
			elseif self.hydro > -100 and self.hydro < 100 then
				self.hydro = self.hydro - .5*input;
			end;
		end;
		self.oldInput = input;
			
		if self.motor.speedLevel ~= 0 then
			self.hydro = 0;
		end;
		
		self.motor.maxRpm[3] = math.abs(self.hydro)*self.gears[self.gearNum]/100;
		if self.hydro ~= 0 then
			local acceleration = self.hydro/math.abs(self.hydro);
			if self.firstTimeRun and self.steeringEnabled then
                WheelsUtil.updateWheelsPhysics(self, dt, self.lastSpeed, acceleration, false, self.requiredDriveMode)
            end;
		end;
	end;
	-- motorMBsound	
	if self.isMotorStarted and self.motorMBSound ~= nil and self.playMotorSoundTime <= self.time and self:getIsActiveForSound() then
		setSamplePitch(self.motorMBSound, math.min(self.motorMBSoundPitchOffset + self.motorMBSoundPitchScale*math.abs(self.rpms[1][self.rpmNum] / 60), self.motorMBSoundPitchMax));
		if self.playMotorMBSound then
			playSample(self.motorMBSound, 0, self.motorMBSoundVolume, 0);
			self.playMotorMBSound = false;
		end;
	end;

	if self.isEntered == nil then
	        stopSample(self.motorMBSound);
	end;
end;

function MBgearbox:draw()
		if self.HUDActive then
			if self.isMotorStarted then
				-- g_currentMission:addExtraPrintText(" last"..string.format("%d",self.lastRoundPerMinute));
				-- g_currentMission:addExtraPrintText(" last"..string.format("%d",self.oldInput *100));
				setTextBold(true);
				setTextColor(0, 0, 0, 1.0);
				renderText(0.909, 0.24, 0.0250, string.format("%4d ",self.rpms[2][self.rpmNum]).."rpm");
				if self.motor.speedLevel == 0 or self.motor.speedLevel == 3 then
					renderText(0.907, 0.27, 0.055,string.format("%d ",self.gearNum));
					local hydro = math.floor((self.hydro+2.5)/5)*5;
					renderText(0.932, 0.28, 0.0250, string.format("%d ",hydro).."%");
				end;
			end;
		end;
end;
